from __future__ import absolute_import, print_function, unicode_literals
from __future__ import absolute_import, print_function, unicode_literals

import re

import requests
import traceback
import sys

from requests.auth import HTTPBasicAuth

from payfacMPSdk import (utils)

conf = utils.Configuration()

PAYFAC_CONTENT_TYPE = "application/com.vantivcnp.payfac-v14+xml"

PAYFAC_API_HEADERS = {"Accept": PAYFAC_CONTENT_TYPE,
                          "Content-Type": PAYFAC_CONTENT_TYPE}

HTTP_ERROR_MESSAGE = "Error with Https Request, Please Check Proxy and Url configuration"


def http_get_retrieval_request(url_suffix, config=conf):

    url = getattr(config, 'url')
    # print("url -> "+url+"\n")
    request_url = url + url_suffix
    # request_url = "https://www.testvantivcnp.com/sandbox/payfac" + url_suffix

    try:
        http_response = requests.get(request_url, headers=PAYFAC_API_HEADERS,
                                     auth=HTTPBasicAuth(config.username, config.password))

    except requests.RequestException:
        traceback.print_exc()
        raise utils.PayfacError(HTTP_ERROR_MESSAGE)

    print_to_console("\nGET request to:", request_url, config)
    validate_response(http_response)
    print_to_console("\nResponse :", http_response.text, config)
    return utils.generate_response(http_response)


def http_post_request(url_suffix, request_xml, config=conf):
    request_url = config.url.encode('utf-8') + url_suffix
    print(config.url)
    try:
        http_response = requests.post(request_url,
                                      headers=PAYFAC_API_HEADERS,
                                      auth=HTTPBasicAuth(config.username, config.password),
                                      data=request_xml)
    except requests.RequestException:
        raise utils.PayfacError(HTTP_ERROR_MESSAGE)

    print_to_console("\nPOST request to:", request_url, config)
    validate_response(http_response)
    print_to_console("\nResponse :", http_response.text, config)
    return utils.generate_response(http_response)

def http_put_request(url_suffix, request_xml, config=conf):
    request_url = config.url.encode('utf-8') + url_suffix;
    try:
        http_response = requests.put(request_url, headers=PAYFAC_API_HEADERS,
                                     auth=HTTPBasicAuth(config.username, config.password),
                                     data=request_xml)
    except requests.RequestException:
        raise utils.PayfacError(HTTP_ERROR_MESSAGE)

    print_to_console("\nPUT request to:", request_url, config)
    print_to_console("\nRequest :", request_xml, config)
    validate_response(http_response)
    print_to_console("\nResponse :", http_response.text, config)
    return utils.generate_response(http_response)


def http_delete_request(url_suffix,config=conf):
    request_url = config.url + url_suffix

    try:
        http_response = requests.delete(request_url, headers=PAYFAC_API_HEADERS,auth=HTTPBasicAuth(config.username, config.password))

    except requests.RequestException:
        raise utils.PayfacError(HTTP_ERROR_MESSAGE)

    print_to_console("\nDELETE request to:", request_url, config)
    validate_response(http_response)
    print_to_console("\nResponse :", http_response.text, config)
    return utils.generate_response(http_response)





def _generate_error_data(error_response):
    error_list = error_response['errors']['error']
    error_message = ""
    prefix = ""
    for error in error_list:
        print(error)
        error_message += prefix + error
        prefix = "\n"
    return error_list, error_message

def validate_response(http_response, config=conf):
    """check the status code of the response
    :param http_response: http response generated
    :return: raises an exception
    """
    # Check empty response
    if http_response is None:
        raise utils.PayfacError("There was an exception while fetching the response")
    if http_response.headers._store.get('content-type') is not None:
        content_type = http_response.headers._store['content-type'][1]
    else:
        content_type = ''

    if (http_response.status_code != 200) & (http_response.status_code !=201):
        if PAYFAC_CONTENT_TYPE in content_type:
            error_response = utils.generate_error_response(http_response)
            print_to_console("\nResponse :", http_response.text, config)
            error_list, error_message = _generate_error_data(error_response)
            raise utils.PayfacWebError(error_message, str(http_response.status_code), error_list)
        raise utils.PayfacWebError(http_response, str(http_response.status_code))


def neuter_xml(xml_string):
    if sys.version_info[0] >= 3:
        xml_string = str(xml_string)
    xml_string = re.sub(r"<token>.*</token>", "<token>****</token>", xml_string)
    xml_string = re.sub(r"<cardNumberLast4>.*</cardNumberLast4>", "<cardNumberLast4>****</cardNumberLast4>", xml_string)
    return xml_string

def print_to_console(prefix_message, xml_string, config=conf):
    if config.printXml:
        if config.neuterXml:
            xml_string = neuter_xml(xml_string)
        print(prefix_message, xml_string)





from __future__ import absolute_import, print_function, unicode_literals

import xmlschema
import os
import sys
import pkg_resources

if sys.version_info[0] < 3:
    from StringIO import StringIO
else:
    from io import StringIO

from payfacMPSdk import communication, utils, version as SdkVersion

SERVICE_ROUTE1 = "/legalentity/"

SERVICE_ROUTE2 = "/submerchant"
"""
/////////////////////////////////////////////////////
            subMerchantRetrievalResponse APIs:
/////////////////////////////////////////////////////
"""
package_root = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
sys.path.insert(0, package_root)
version = utils.Configuration().VERSION
xsd_name = 'merchant-onboard-api-v%s.xsd' % version
xsd_path = pkg_resources.resource_filename('payfacMPSdk', 'schema/' + xsd_name)
my_schema = xmlschema.XMLSchema(xsd_path)

def get_by_subMerchantId(legalEntityId, subMerchantId):
    url_suffix = SERVICE_ROUTE1  + legalEntityId + SERVICE_ROUTE2 +"/"+ subMerchantId
    return communication.http_get_retrieval_request(url_suffix)

def post_by_legalEntity(legalEntityId,subMerchantCreateRequest):
    subMerchantCreateRequest.set_sdkVersion(SdkVersion.RELEASE)
    subMerchantCreateRequest.set_language(SdkVersion.LANGUAGE)
    stringIO = StringIO()
    subMerchantCreateRequest.export(stringIO, 0, pretty_print=False)
    request = stringIO.getvalue()
    request = request.replace("tns:", "")
    request = request.replace(":tns", "")
    if my_schema.is_valid(request):
        url_suffix = (SERVICE_ROUTE1 + legalEntityId + SERVICE_ROUTE2).encode('utf-8')
        return communication.http_post_request(url_suffix, request.encode('utf-8'))
    else:
        raise utils.PayfacSchemaError("Input is not compatible with schema")

def put_by_subMerchantId(legalEntityId,subMerchantId, subMerchantUpdateRequest):

    stringIO = StringIO()
    subMerchantUpdateRequest.export(stringIO, 0)
    request = stringIO.getvalue()
    request = request.replace("tns:", "")
    request = request.replace(":tns", "")
    if my_schema.is_valid(request):
        url_suffix = (SERVICE_ROUTE1 + legalEntityId + SERVICE_ROUTE2 + "/" + subMerchantId).encode('utf-8')
        return communication.http_put_request(url_suffix, request.encode('utf-8'))
    else:
        raise utils.PayfacSchemaError("Input is not compatible with schema")



from __future__ import absolute_import, print_function, unicode_literals

from payfacMPSdk import communication

SERVICE_ROUTE = "/mcc"

"""
/////////////////////////////////////////////////////
            mcc APIs:
/////////////////////////////////////////////////////
"""


def get_mcc():
    return communication.http_get_retrieval_request(SERVICE_ROUTE)


import os
import json
import xmlschema
import pkg_resources
import sys

package_root = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
sys.path.insert(0, package_root)
version = u'14'
xsd_name = 'merchant-onboard-api-v%s.xsd' % version
#retrieve xsd file using package manager
xsd_path = pkg_resources.resource_filename('payfacMPSdk', 'schema/' + xsd_name)
my_schema = xmlschema.XMLSchema(xsd_path)

class Configuration(object):
    """Setup Configuration variables.

    Attributes:
        user (Str): authentication.user
        password (Str): authentication.password
        merchant_id (Str): The unique string to identify the merchant within the system.
        url (Str): Url for server.
        proxy (Str): Https proxy server address. Must start with "https://"
        print_xml (Str): Whether print request and response xml
    """
    VERSION = version
    if 'PAYFAC_MP_SDK_CONFIG' in os.environ:
        _CONFIG_FILE_PATH = os.path.join(os.environ['PAYFAC_MP_SDK_CONFIG'])
    else:
        _CONFIG_FILE_PATH = os.path.join(os.path.expanduser("~"), ".payfac_mp_sdk.conf")


    def __init__(self, conf_dict=dict()):

        # print("config file path -> "+self._CONFIG_FILE_PATH)

        attr_dict = {
            'merchant_id': '',
            'neuterXml': False,
            'password': '',
            'printXml': False,
            'proxy': '',
            'url': 'https://www.testvantivcnp.com/sandbox/payfac',
            'username': ''}

        for k in attr_dict:
            setattr(self, k, attr_dict[k])

        # override values by loading saved conf
        try:
            with open(self._CONFIG_FILE_PATH, 'r') as config_file:
                config_json = json.load(config_file)
                # print ("overriding config values here \n")
                for ke in attr_dict:
                    if ke in config_json and config_json[ke]:
                        #print(ke + "\t" + config_json[ke])
                        setattr(self, ke, config_json[ke])
        except:
            # If get any exception just pass.
            pass

        # override values by args
        if conf_dict:
            for key in conf_dict:
                if key in attr_dict:
                    setattr(self, key, conf_dict[key])
                # else:
                #     raise payfacError('"%s" is NOT an attribute of conf' % k)


    def save(self):
        """Save Class Attributes to .payfac_mp_sdk.conf

        Returns:
            full path for configuration file.

        Raises:
            IOError: An error occurred
        """
        with open(self._CONFIG_FILE_PATH, 'w') as config_file:
            json.dump(vars(self), config_file)
        return self._CONFIG_FILE_PATH


def generate_response(http_response):
    response_text = http_response.text
    #for python 2, must be encoded before passed to validation by xmlschema
    if sys.version_info[0] < 3:
        return convert_to_dict(response_text.encode('utf-8'))
    #python 3 and above can be passed as text
    else:
        return convert_to_dict(response_text)


def convert_to_dict(xml_response):
    if(not (my_schema.is_valid(xml_response))): raise PayfacSchemaError("Input is not compatible with schema")
    response_dict = my_schema.to_dict(xml_response)
    if response_dict['@xmlns'] != "":
        _create_lists(response_dict)
        return response_dict
    else:
        raise PayfacError("Invalid Format")


def _create_lists(response_dict):
    if "payfacCase" in response_dict:
        _create_list("payfacCase", response_dict)

        for case in response_dict["payfacCase"]:
            if "activity" in case:
                _create_list("activity", case)

    if "errors" in response_dict:
        _create_list("error", response_dict["errors"])


# if there is only one element for the given key in container, create a list for it
def _create_list(element_key, container):
    element_value = container[element_key]
    if element_value != "" and not isinstance(element_value, list):
        container[element_key] = [element_value]


def generate_error_response(http_response, return_format='dict'):
    return convert_to_dict(http_response.text)

class PayfacError(Exception):

    def __init__(self, message):
        self.message = message

class PayfacWebError(Exception):

    def __init__(self, message, code, error_list=None):
        self.message = message
        self.code = code
        self.error_list = error_list

class PayfacSchemaError(Exception):
    def __init__(self,message):
        self.message = message



#!/usr/bin/env python

from __future__ import absolute_import, division, print_function

if sys.version_info[0] < 3:
    from builtins import input

import os
import sys
import tempfile

import six

package_root = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
sys.path.insert(0, package_root)

from payfacMPSdk import utils


def ask_user():
    attrs = [
        'username',
        'password',
        'merchant_id',
        'proxy',
        'printXml',
        'neuterXml'
    ]
    attr_dict = {
        'username': '',
        'password': '',
        'merchant_id': '',
        'url': '',
        'proxy': '',
        'printXml': 'n',
        'neuterXml': 'n'
    }
    attr_valid_dict = {

        'neuterXml': {
            'y': True,
            'n': False,
        },
        'printXml': {
            'y': True,
            'n': False,
        }
    }
    attr_des_dict = {
        'username': 'Please input your presenter user name: ',
        'password': 'Please input your presenter password: ',
        'merchant_id': 'Please input your merchantId: ',
        'proxy': 'If you want to using https proxy, please input your proxy server address. Must start with "https://"',
        'printXml': 'Do you want to print xml in console? y for Yes, n for No.',
        'neuterXml': 'Do you want to hide sensitive data in printed xml? y for Yes, n for No.'
    }
    print(CC.bpurple('"Welcome to the Merchant Provisioner PayFac Python SDK"'))
    print('''    Please enter values for the following settings
    (just press Enter to accept a default value, if one is given in brackets).''')

    for attr in attrs:
        while True:
            print(gene_prompt(attr, attr_dict, attr_valid_dict, attr_des_dict))
            if six.PY3:
                x = input('')
            else:
                x = input('')
            if not x:
                x = attr_dict[attr]
            if attr in attr_valid_dict:
                if x.lower() in attr_valid_dict[attr]:
                    x = attr_valid_dict[attr][x.lower()]
                else:
                    print('Invalid input for "%s" = "%s"' % (attr, x))
                    continue
            attr_dict[attr] = x
            break
    environmentConfig(attr_dict)
    conf = utils.Configuration()
    for k in attr_dict:
        setattr(conf, k, attr_dict[k])
    print(CC.bgreen('Configurations have saved at: %s ' % conf.save()))
    print(CC.bpurple('Successful!'))


def environmentConfig(attr_dict):
    Environment = {
        "SANDBOX": 'https://www.testvantivcnp.com/sandbox/payfac',
        "PRELIVE": 'https://payfac.vantivprelive.com',
        "POSTLIVE": 'https://services.vantivpostlive.com',
        "PRODUCTION": 'https://services.vantivcnp.com',
        "OTHER": 'You will be asked for all the values',
    }
    badInput = False
    continueTakeInput = True

    while continueTakeInput:
        if badInput: print("====== Invalid choice enetered ==========")
        print("Please choose an environment from the following list (example: 'prelive'): ");
        for env in Environment:
            print(env, Environment[env])
        userInput = input('')
        if (userInput in Environment) and (userInput != 'OTHER'):
            attr_dict['url'] = Environment[userInput]
            continueTakeInput = False
        elif (userInput == 'OTHER'):
            print(
                "Please input the URL for online transactions (ex: https://www.testvantivcnp.com/sandbox/communicator/online): ");
            userInput = input('')
            attr_dict['url'] = userInput
            continueTakeInput = False
        else:
            continueTakeInput = True
            badInput = True


def gene_prompt(attr, attr_dict, attr_valid_dict, attr_des_dict):
    if attr_dict[attr]:
        if attr in attr_valid_dict:
            option_str = CC.bcyan('Please select from following options:\n')
            for k in attr_valid_dict[attr]:
                _opt = attr_valid_dict[attr][k]
                if isinstance(_opt, bool):
                    _opt = 'True' if _opt else 'False'
                option_str += '%s - %s\n' % (CC.bgreen(k), CC.byellow(_opt))

            prompt = '\n%s\n%s%s [%s]: ' % \
                     (CC.bcyan(attr_des_dict[attr]), option_str, CC.bred(attr), CC.bgreen(attr_dict[attr]))
        else:
            prompt = '\n%s\n%s [%s]: ' % (CC.bcyan(attr_des_dict[attr]), CC.bred(attr), attr_dict[attr])
    else:
        prompt = '\n%s\n%s: ' % (CC.bcyan(attr_des_dict[attr]), CC.bred(attr))
    return prompt


# noinspection PyClassHasNoInit
class CC:
    # RESET
    COLOR_OFF = '\033[0m'  # TEXT RESET

    # REGULAR COLORS
    BLACK = '\033[0;30m'  # BLACK
    RED = '\033[0;31m'  # RED
    GREEN = '\033[0;32m'  # GREEN
    YELLOW = '\033[0;33m'  # YELLOW
    BLUE = '\033[0;34m'  # BLUE
    PURPLE = '\033[0;35m'  # PURPLE
    CYAN = '\033[0;36m'  # CYAN
    WHITE = '\033[0;37m'  # WHITE

    # BOLD
    BBLACK = '\033[1;30m'  # BLACK
    BRED = '\033[1;31m'  # RED
    BGREEN = '\033[1;32m'  # GREEN
    BYELLOW = '\033[1;33m'  # YELLOW
    BBLUE = '\033[1;34m'  # BLUE
    BPURPLE = '\033[1;35m'  # PURPLE
    BCYAN = '\033[1;36m'  # CYAN
    BWHITE = '\033[1;37m'  # WHITE

    # UNDERLINE
    UBLACK = '\033[4;30m'  # BLACK
    URED = '\033[4;31m'  # RED
    UGREEN = '\033[4;32m'  # GREEN
    UYELLOW = '\033[4;33m'  # YELLOW
    UBLUE = '\033[4;34m'  # BLUE
    UPURPLE = '\033[4;35m'  # PURPLE
    UCYAN = '\033[4;36m'  # CYAN
    UWHITE = '\033[4;37m'  # WHITE

    @classmethod
    def black(cls, _str):
        return cls.BLACK + _str + cls.COLOR_OFF

    @classmethod
    def red(cls, _str):
        return cls.RED + _str + cls.COLOR_OFF

    @classmethod
    def green(cls, _str):
        return cls.GREEN + _str + cls.COLOR_OFF

    @classmethod
    def yellow(cls, _str):
        return cls.YELLOW + _str + cls.COLOR_OFF

    @classmethod
    def blue(cls, _str):
        return cls.BLUE + _str + cls.COLOR_OFF

    @classmethod
    def purple(cls, _str):
        return cls.PURPLE + _str + cls.COLOR_OFF

    @classmethod
    def cyan(cls, _str):
        return cls.CYAN + _str + cls.COLOR_OFF

    @classmethod
    def white(cls, _str):
        return cls.WHITE + _str + cls.COLOR_OFF

    @classmethod
    def ublack(cls, _str):
        return cls.UBLACK + _str + cls.COLOR_OFF

    @classmethod
    def ured(cls, _str):
        return cls.URED + _str + cls.COLOR_OFF

    @classmethod
    def ugreen(cls, _str):
        return cls.UGREEN + _str + cls.COLOR_OFF

    @classmethod
    def uyellow(cls, _str):
        return cls.UYELLOW + _str + cls.COLOR_OFF

    @classmethod
    def ublue(cls, _str):
        return cls.UBLUE + _str + cls.COLOR_OFF

    @classmethod
    def upurple(cls, _str):
        return cls.UPURPLE + _str + cls.COLOR_OFF

    @classmethod
    def ucyan(cls, _str):
        return cls.UCYAN + _str + cls.COLOR_OFF

    @classmethod
    def uwhite(cls, _str):
        return cls.UWHITE + _str + cls.COLOR_OFF

    @classmethod
    def bblack(cls, _str):
        return cls.BBLACK + _str + cls.COLOR_OFF

    @classmethod
    def bred(cls, _str):
        return cls.BRED + _str + cls.COLOR_OFF

    @classmethod
    def bgreen(cls, _str):
        return cls.BGREEN + _str + cls.COLOR_OFF

    @classmethod
    def byellow(cls, _str):
        return cls.BYELLOW + _str + cls.COLOR_OFF

    @classmethod
    def bblue(cls, _str):
        return cls.BBLUE + _str + cls.COLOR_OFF

    @classmethod
    def bpurple(cls, _str):
        return cls.BPURPLE + _str + cls.COLOR_OFF

    @classmethod
    def bcyan(cls, _str):
        return cls.BCYAN + _str + cls.COLOR_OFF

    @classmethod
    def bwhite(cls, _str):
        return cls.BWHITE + _str + cls.COLOR_OFF


def main(argv=sys.argv):
    ask_user()


if __name__ == '__main__':
    sys.exit(main(sys.argv))



# -*- coding: utf-8 -*-
import sys
from setuptools import setup

# Require Python 2.7.9 or higher or Python 3.4 or higher
if (sys.version_info[:3] < (2, 7, 9)) or ((sys.version_info[0] == 3) and sys.version_info[:2] < (3, 4)):
    raise ValueError('''PyXB requires:
  Python2 version 2.7.9 or later; or
  Python3 version 3.4 or later
(You have %s.)''' % (sys.version,))

setup(
    name='PayfacMpSDK',
    version='14.0.0',
    description='Worldpay payfac SDK',
    author='Worldpay',
    author_email='SDKSupport@vantiv.com',
    url='https://developer.vantiv.com/community/ecommerce',
    packages=['payfacMPSdk', 'payfacMPSdk.schema', 'scripts'],
    package_data={'payfacMPSdk.schema': ['*.xsd']},
    install_requires=[
        'paramiko>=1.14.0',
        'requests>=2.21.0 ',
        'six>=1.10.0',
        'xmlschema>=1.0.3, <=1.0.18',
        'generateDS>=2.29.24',
        'unittest2>=1.1.0',
        'python-dateutil>=2.7.3',
        'setuptools',
        'mock', 'lxml',
        'wheel'
    ],
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Office/Business :: Financial',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    entry_points={
        'console_scripts': [
            'payfac_mp_sdk_setup = scripts.payfac_mp_sdk_setup:main',
        ],
    },
    long_description='''Worldpay Python Payfac SDK
=====================================================

.. _`WorldPay eCommerce`: https://developer.vantiv.com/community/ecommerce

About WorldPay eCommerce
----------------------
`WorldPay eCommerce`_ powers the payment processing engines for leading companies that sell directly to consumers through  internet retail, direct response marketing (TV, radio and telephone), and online services. WorldPay eCommerce is the leading authority in card-not-present (CNP) commerce, transaction processing and merchant services.


About this SDK
--------------
The WorldPay Python PayFac SDK is a Python implementation of the `WorldPay eCommerce`_ PayFac API. This SDK was created to make it as easy as possible to manage your PayFac using WorldPay eCommerce API. This SDK utilizes the HTTPS protocol to securely connect to WorldPay eCommerce. Using the SDK requires coordination with the WorldPay eCommerce team in order to be provided with credentials for accessing our systems.

Each Python SDK release supports all of the functionality present in the associated WorldPay eCommerce PayFac API version (e.g., SDK v2.1.0 supports WorldPay eCommerce PayFac API v2.1). Please see the PayFac API reference guide to get more details on what the WorldPay eCommerce PayFac engine supports.

This SDK was implemented to support the Python programming language and was created by WorldPay eCommerce. Its intended use is for online and batch transaction processing utilizing your account on the WorldPay eCommerce payments engine.

See LICENSE file for details on using this software.

Please contact `WorldPay eCommerce`_ to receive valid merchant credentials in order to run test successfully or if you require assistance in any way.  We are reachable at sdksupport@Vantiv.com

Dependencies
------------
* pyxb v1.2.5 : http://pyxb.sourceforge.net/
* paramiko v1.14.0: http://www.paramiko.org/
* requests v2.13.0: http://docs.python-requests.org/en/master/
* six v1.10.0: https://github.com/benjaminp/six
* xmltodict 0.10.2: https://github.com/martinblech/xmltodict

Setup
-----
* Run payfac_mp_sdk_setup and answer the questions.

.. code:: bash

   payfac_mp_sdk_setup

EXAMPLE
-------
Using dict
..........
.. code-block:: python

    #Example for PayFac SDK
    from __future__ import print_function, unicode_literals

    from cnpsdk import *

    # Initial Configuration object. If you have saved configuration in '.payfac_mp_sdk.conf' at system environment
    # variable: PAYFAC_SDK_CONFIG or user home directory, the saved configuration will be automatically load.
    conf = utils.Configuration()

    # Configuration need following attributes for PayFac requests:
    # user = ''
    # password = ''
    # merchantId = ''
    # url = 'https://www.testvantivcnp.com/sandbox/communicator/online'
    # proxy = ''

    # Retrieving information about a LegalEntity by legalentityID:
    response = payfac_legalEntity.get_by_legalEntityId(legalentityId)

    # Update a LegalEntity
    request = "......(some request)"
    response = payfac_legalEntity.put_by_legalEntityId(legalentityId, request)

    # Create a LegalEntity
    request = "......(some request)"
    response = payfac_legalEntity.post_by_legalEntity(request)

''',
    long_description_content_type='text/markdown',
)
